.. image:: https://img.shields.io/travis/rwanyoike/time2relax.svg
   :target: https://travis-ci.org/rwanyoike/time2relax

.. image:: https://img.shields.io/codecov/c/gh/rwanyoike/time2relax.svg
   :target: https://codecov.io/gh/rwanyoike/time2relax

.. image:: https://img.shields.io/pypi/v/time2relax.svg
   :target: https://pypi.python.org/pypi/time2relax

.. image:: https://img.shields.io/pypi/pyversions/time2relax.svg
   :target: https://pypi.python.org/pypi/time2relax

.. image:: https://img.shields.io/pypi/l/time2relax.svg
   :target: https://pypi.python.org/pypi/time2relax
